@@ -23,7 +23,6 @@ from keras.layers import (
     MaxPooling2D,
     BatchNormalization,
     Lambda,
-    AveragePooling2D,
     UpSampling2D,
 )
 from keras.layers.advanced_activations import LeakyReLU
@@ -33,9 +32,7 @@ import hashlib
 import cryolo.utils as utils
 
 dir_script = os.path.dirname(__file__)
-init_weights = (
-    "https://ndownloader.figshare.com/files/16406843"
-)  # ftp://ftp.gwdg.de/pub/misc/sphire/crYOLO-INIT/full_yolo_backend.h5'
+init_weights = "https://ndownloader.figshare.com/files/16406843"  # ftp://ftp.gwdg.de/pub/misc/sphire/crYOLO-INIT/full_yolo_backend.h5'
 init_weights_md5 = "647974a82106d7a0e5663a29a78a4598"
 FULL_YOLO_BACKEND_PATH = os.path.join(dir_script, "full_yolo_backend.h5")
 
@@ -114,7 +111,7 @@ class CrYoloFeature(BaseFeatureExtractor):
 
         # name of first layer
         name_first_layer = "conv_1"
-        if input_depth is 1:
+        if input_depth == 1:
             name_first_layer = "conv_1_depth1"
 
         # the function to implement the orgnization layer (thanks to github.com/allanzelener/YAD2K)
@@ -265,7 +262,7 @@ class PhosaurusNetFeature(BaseFeatureExtractor):
 
         # name of first layer
         name_first_layer = "conv_1"
-        if input_depth is 1:
+        if input_depth == 1:
             name_first_layer = "conv_1_depth1"
 
         # Layer 1
@@ -453,7 +450,7 @@ class FullYoloFeature(BaseFeatureExtractor):
 
         # name of first layer
         name_first_layer = "conv_1"
-        if input_depth is 1:
+        if input_depth == 1:
             name_first_layer = "conv_1_depth1"
 
         # the function to implement the orgnization layer (thanks to github.com/allanzelener/YAD2K)
