@@ -12,8 +12,6 @@
 # ---------------------------------------------------------------------------
 #
 
-import sys
-
 
 def generate_config_file(
     config_out_path,
@@ -72,7 +70,6 @@ def generate_config_file(
             "class_scale": class_scale,
             "saved_weights_name": saved_weights_name,
             "debug": debug,
-            "log_path": log_path,
         }
         dict["train"] = train_dict
 
@@ -82,6 +79,11 @@ def generate_config_file(
             "valid_times": valid_times,
         }
         dict["valid"] = valid_dict
+    if log_path:
+        other_dict = {
+            "log_path": log_path,
+        }
+        dict["other"] = other_dict
 
     from json import dump
 
@@ -154,8 +156,9 @@ def get_box_size(config):
     if "particle_diameter" in config["model"]:
         box_height = config["model"]["particle_diameter"]
         box_width = config["model"]["particle_diameter"]
-    elif len(config["model"]["anchors"]) == 2:
-        box_height, box_width = config["model"]["anchors"]
+    elif "anchors" in config["model"]:
+        if len(config["model"]["anchors"]) == 2:
+            box_height, box_width = config["model"]["anchors"]
     else:
-        sys.exit("You have to specify the 'particle_diameter' in your config. Stop.")
+        box_height, box_width = 0, 0
     return box_width, box_height
