@@ -2,21 +2,26 @@ from gooey import Gooey, GooeyParser
 import argparse
 import os
 import cryolo.config_tools as config_tools
-import multiprocessing
 import cryolo.__init__ as ini
-import cryoloBM.boxmanager as boxmanager
+
 
 def config_boxmanager_parser(parser_config):
     config_required_group = parser_config.add_argument_group(
-        "General arguments",
-        "Options to start the box manager.",
+        "General arguments", "Options to start the box manager.",
     )
 
-    config_required_group.add_argument("-i", "--image_dir", help="Path to image directory.", widget="DirChooser")
+    config_required_group.add_argument(
+        "-i", "--image_dir", help="Path to image directory.", widget="DirChooser"
+    )
 
-    config_required_group.add_argument("-b", "--box_dir", help="Path to box directory.", widget="DirChooser")
+    config_required_group.add_argument(
+        "-b", "--box_dir", help="Path to box directory.", widget="DirChooser"
+    )
+
+    config_required_group.add_argument(
+        "--wildcard", help="Wildcard for selecting specific images (e.g *_new_*.mrc)"
+    )
 
-    config_required_group.add_argument("--wildcard", help="Wildcard for selecting specific images (e.g *_new_*.mrc)")
 
 def config_configuration_parser(parser_config):
     config_required_group = parser_config.add_argument_group(
@@ -232,7 +237,6 @@ def config_configuration_parser(parser_config):
         help='Irrelevant, as crYOLO only has the class "particle".',
     )
 
-
     config_training_group.add_argument(
         "--debug",
         action="store_true",
@@ -260,8 +264,7 @@ def config_configuration_parser(parser_config):
     )
 
     config_other_group = parser_config.add_argument_group(
-        "Other option",
-        "Other options that does not fit anywhere else",
+        "Other option", "Other options that does not fit anywhere else",
     )
 
     config_other_group.add_argument(
@@ -276,7 +279,6 @@ def create_parser():
     )
     subparsers = parent_parser.add_subparsers(help="sub-command help")
 
-
     # Config generator
     parser_config = subparsers.add_parser(
         "config",
@@ -303,7 +305,7 @@ def create_parser():
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
 
-    #import cryolo.predict as predict
+    # import cryolo.predict as predict
     from cryolo.predict import create_parser as create_predict_parser
 
     create_predict_parser(parser_pick)
@@ -315,7 +317,8 @@ def create_parser():
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     from cryolo.eval import create_parser as create_eval_parser
-    #import cryolo.eval as evaluation
+
+    # import cryolo.eval as evaluation
 
     create_eval_parser(parser_eval)
 
@@ -336,21 +339,23 @@ PARSER = None
 def main():
     import sys
 
-
     args = PARSER.parse_args()
 
     print("#####################################################")
-    print("Important debugging information.\nIn case of any problems, please provide this information.")
+    print(
+        "Important debugging information.\nIn case of any problems, please provide this information."
+    )
     print("#####################################################")
     for cmd_arg in sys.argv:
         if cmd_arg.startswith("-"):
             print("")
-        print(cmd_arg,end=' ')
+        print(cmd_arg, end=" ")
     print("")
     print("#####################################################")
 
     if "config" in sys.argv[1]:
         import cryolo.utils as util
+
         util.check_for_updates()
 
         filter = None
@@ -409,7 +414,6 @@ def main():
     elif "boxmanager" in sys.argv[1]:
         from cryoloBM import boxmanager
 
-
         boxmanager.start_boxmanager(args.image_dir, args.box_dir, args.wildcard)
 
 
@@ -418,10 +422,10 @@ def _main_():
     import sys
 
     PARSER = create_parser()
-   # try:
-   #     multiprocessing.set_start_method("spawn")
-   # except RuntimeError:
-   #     print("Ignore set start method")
+    # try:
+    #     multiprocessing.set_start_method("spawn")
+    # except RuntimeError:
+    #     print("Ignore set start method")
 
     kwargs = {"terminal_font_family": "monospace", "richtext_controls": True}
 
@@ -442,8 +446,8 @@ def _main_():
 
 
 if __name__ == "__main__":
-    #try:
+    # try:
     #    multiprocessing.set_start_method("spawn")
-    #except RuntimeError:
+    # except RuntimeError:
     #    print("Ignore set start method")
     _main_()
