@@ -18,7 +18,7 @@ import difflib
 import json
 import multiprocessing
 import os
-
+from . import utils
 import numpy as np
 import terminaltables
 
@@ -60,9 +60,10 @@ argparser = argparse.ArgumentParser(
 
 def create_parser(parser):
     required_group = parser.add_argument_group(
-        "Required arguments", "These options are required to run crYOLO evaluation. In most cases you want to use a runfile to evaluate"
-                              "your model. In case you want to specify the ground truth data, leave the runfile field empty and go to the optional"
-                              "arguments."
+        "Required arguments",
+        "These options are required to run crYOLO evaluation. In most cases you want to use a runfile to evaluate"
+        "your model. In case you want to specify the ground truth data, leave the runfile field empty and go to the optional"
+        "arguments.",
     )
     required_group.add_argument(
         "-c",
@@ -122,15 +123,24 @@ def create_parser(parser):
     )
 
     optional_group = parser.add_argument_group(
-        "Optional arguments", "These options are optional to run crYOLO evaluation. Here you can"
-                              "specify specific images and boxes as ground truth that should be "
-                              "used to calcuate the statistics."
+        "Optional arguments",
+        "These options are optional to run crYOLO evaluation. Here you can"
+        "specify specific images and boxes as ground truth that should be "
+        "used to calcuate the statistics.",
     )
 
-    optional_group.add_argument("-i", "--images", help="Path folder with test images (ground truth)")
+    optional_group.add_argument(
+        "-i",
+        "--images",
+        help="Path folder with test images (ground truth)",
+        widget="DirChooser",
+    )
 
     optional_group.add_argument(
-        "-b", "--boxfiles", help="path to folder with box files (ground truth)"
+        "-b",
+        "--boxfiles",
+        help="path to folder with box files (ground truth)",
+        widget="DirChooser",
     )
 
     optional_group.add_argument(
@@ -496,59 +506,6 @@ def main(args=None):
     print("Wrote evaluation results to", path_output)
 
 
-def get_num_fine_tune_layers(path_weights):
-    import h5py
-
-    with h5py.File(path_weights, mode="r") as f:
-        try:
-            num_free_layers = int(list(f["num_free_layers"])[0])
-        except KeyError:
-            num_free_layers = None
-    return num_free_layers
-
-
-def get_anchors(config, path_weights):
-    is_single_anchor = config["model"]["anchors"] == 2
-    grid_w, grid_h = config_tools.get_gridcell_dimensions(config)
-    anchors = None
-    import h5py
-
-    with h5py.File(path_weights, mode="r") as f:
-        try:
-            anchors = list(f["anchors"])
-        except KeyError:
-            anchors = None
-
-    if is_single_anchor and anchors is None:
-        num_patches = 1
-        if "num_patches" in config["model"]:
-            num_patches = config["model"]["num_patches"]
-
-        img_width = 4096.0 / num_patches
-        img_height = 4096.0 / num_patches
-        cell_w = img_width / grid_w
-        cell_h = img_height / grid_h
-
-        box_width, box_height = config_tools.get_box_size(config)
-
-        anchor_width = 1.0 * box_width / cell_w
-        anchor_height = 1.0 * box_height / cell_h
-        anchors = [anchor_width, anchor_height]
-    elif anchors is None:
-        num_patches = 1
-        if "num_patches" in config["model"]:
-            num_patches = config["model"]["num_patches"]
-        img_width = 4096.0 / num_patches
-        img_height = 4096.0 / num_patches
-        cell_w = img_width / grid_w
-        cell_h = img_height / grid_h
-        anchors = np.array(config["model"]["anchors"], dtype=float)
-        anchors[::2] = anchors[::2] / cell_w
-        anchors[1::2] = anchors[1::2] / cell_h
-
-    return anchors
-
-
 def prepare_datasets(
     path_config, path_weights, path_boxfiles, path_runfile, path_images
 ):
@@ -638,23 +595,20 @@ def prepare_datasets(
     ###############################
     #   Make the model
     ###############################
-    depth = 1
     num_gpus = 1
-
     backend_weights = None
+    anchors = utils.get_anchors(config, path_weights=path_weights)
+    num_free_layers = utils.get_num_fine_tune_layers(path_weights)
 
-    anchors = get_anchors(config, path_weights)
-    num_free_layers = get_num_fine_tune_layers(path_weights)
     if num_free_layers is None:
         num_free_layers = 2
     if "backend_weights" in config["model"]:
         backend_weights = config["model"]["backend_weights"]
     from .frontend import YOLO
+
     yolo = YOLO(
         architecture=config["model"]["architecture"],
         input_size=config["model"]["input_size"],
-        input_depth=depth,
-        labels=["particle"],
         max_box_per_image=config["model"]["max_box_per_image"],
         anchors=anchors,
         backend_weights=backend_weights,
@@ -678,6 +632,7 @@ def prepare_datasets(
     # USE MULTIGPU
     if num_gpus > 1:
         from keras.utils import multi_gpu_model
+
         parallel_model = multi_gpu_model(yolo.model, gpus=num_gpus)
         yolo.model = parallel_model
 
@@ -708,6 +663,7 @@ def prepare_datasets(
 
         # Predict
         from cryolo import predict
+
         predict_results = predict.do_prediction(
             config_path=path_config,
             weights_path=path_weights,
@@ -717,6 +673,8 @@ def prepare_datasets(
             config_pre=config,
             overlap=overlap_patches,
             yolo=yolo,
+            min_size=None,
+            max_size=None,
         )
 
         # Rescale to image dimensions
@@ -724,28 +682,9 @@ def prepare_datasets(
             image_width = boxes_in_micrograph["img_width"]
             image_height = boxes_in_micrograph["img_height"]
             for box in boxes_in_micrograph["boxes"]:
-                predict.rescale(box,image_height,image_width,box_size)
+                predict.rescale(box, image_height, image_width, box_size)
                 box.x = box.x + box_size / 2
                 box.y = box.y + box_size / 2
-                '''
-                x_ll = int((box.x - box.w / 2) * image_height)  # lower left
-                y_ll = int(
-                    image_width - box.y * image_width - box.h / 2 * image_width
-                )  # lower right
-                boxheight_in_pxl = int(box.h * image_width)
-                boxwidth_in_pxl = int(box.w * image_height)
-
-                delta_boxsize_height = box_size - boxheight_in_pxl
-                delta_boxsize_width = box_size - boxwidth_in_pxl
-                x_ll = x_ll - delta_boxsize_height / 2
-                y_ll = y_ll - delta_boxsize_width / 2
-                boxsize_in_pxl = box_size
-
-                box.x = x_ll + boxsize_in_pxl / 2
-                box.y = y_ll + boxsize_in_pxl / 2
-                box.w = boxsize_in_pxl
-                box.h = boxsize_in_pxl
-                '''
 
         dataset["picks"] = predict_results
 
@@ -798,6 +737,7 @@ def calculate_statics_dataset(foldername, dataset):
     for thresh in arange:
         thresh = round(thresh, 3)
         res = get_precision_recall_f1(dataset, thresh)
+
         if res is not None:
             result_dict[str(thresh)] = res
             precision = result_dict[str(thresh)][1]
@@ -969,7 +909,7 @@ def get_precision_recall_f1(dataset, confidence_threshold):
             images_with_particles = images_with_particles + 1
 
     if images_with_particles == 0:
-        return None
+        return (0, 0, 0, 0, 0, 0)
 
     # --------------------------------------------#
     f1_avg = f1_sum / images_with_particles
