@@ -24,6 +24,7 @@ import sys
 from . import imagereader
 import urllib.request, json
 
+
 class Filament:
     """
     Filament object
@@ -91,6 +92,7 @@ class BoundBox:
         self.y = y
         self.w = w
         self.h = h
+        self.meta = {}
 
         self.c = c
         self.classes = classes
@@ -172,7 +174,6 @@ def resample_filament(filament, distance):
     boxes = filament.boxes
     max_distance = 0
     max_boxa = None
-    max_boxb = None
 
     for i in range(len(boxes)):
         for j in range(len(boxes)):
@@ -181,7 +182,6 @@ def resample_filament(filament, distance):
             dist = box_squared_distance(boxes[i], boxes[j])
             if dist > max_distance:
                 max_boxa = i
-                max_boxb = j
     if max_boxa is not None:
         # Construct a polyline, start from max_boxa
         polyline = []
@@ -241,6 +241,54 @@ def resample_filament(filament, distance):
     return None
 
 
+def get_anchors(config, path_weights=None, image_size=None):
+    import cryolo.config_tools as config_tools
+
+    is_single_anchor = len(config["model"]["anchors"]) == 2
+    num_patches = 1
+    if "num_patches" in config["model"]:
+        num_patches = config["model"]["num_patches"]
+
+    grid_w, grid_h = config_tools.get_gridcell_dimensions(config)
+    anchors = None
+
+    if path_weights:
+        import h5py
+
+        with h5py.File(path_weights, mode="r") as f:
+            try:
+                anchors = list(f["anchors"])
+            except KeyError:
+                anchors = None
+
+    if is_single_anchor and anchors is None:
+
+        if image_size:
+            img_width = float(image_size[0]) / num_patches
+            img_height = float(image_size[1]) / num_patches
+        else:
+            img_width = 4096.0 / num_patches
+            img_height = 4096.0 / num_patches
+        cell_w = img_width / grid_w
+        cell_h = img_height / grid_h
+
+        box_width, box_height = config_tools.get_box_size(config)
+
+        anchor_width = 1.0 * box_width / cell_w
+        anchor_height = 1.0 * box_height / cell_h
+        anchors = [anchor_width, anchor_height]
+    elif anchors is None:
+        img_width = 4096.0 / num_patches
+        img_height = 4096.0 / num_patches
+        cell_w = img_width / grid_w
+        cell_h = img_height / grid_h
+        anchors = np.array(config["model"]["anchors"], dtype=float)
+        anchors[::2] = anchors[::2] / cell_w
+        anchors[1::2] = anchors[1::2] / cell_h
+
+    return anchors
+
+
 def box_squared_distance(boxa, boxb):
     """
     calculates the squared distance between the center of two boxes.
@@ -251,7 +299,6 @@ def box_squared_distance(boxa, boxb):
     return np.square(boxa.x - boxb.x) + np.square(boxa.y - boxb.y)
 
 
-
 def normalize(image, margin_size=0):
     """
     Normalize an image. If wanted, a specified relative margin can be ignored.
@@ -261,7 +308,7 @@ def normalize(image, margin_size=0):
     """
     if margin_size < 0 or margin_size > 1:
         print("Normalization has to be between 0 and 1.")
-        if(margin_size<0):
+        if margin_size < 0:
             margin_size = 0
         else:
             margin_size = 1
@@ -339,6 +386,17 @@ def sigmoid(x):
     return 1.0 / (1.0 + np.exp(-x))
 
 
+def get_num_fine_tune_layers(path_weights):
+    import h5py
+
+    with h5py.File(path_weights, mode="r") as f:
+        try:
+            num_free_layers = int(list(f["num_free_layers"])[0])
+        except KeyError:
+            num_free_layers = None
+    return num_free_layers
+
+
 def filter_image_noise2noise(img_path, model_path, padding=15, batch_size=4):
     """
     Filters an images using JANNI (noise2noise implementation)
@@ -428,6 +486,20 @@ def filter_images_noise2noise_dir(
 
     return filtered_paths
 
+
+def write_command(filename, txt):
+    try:
+        import os
+
+        os.makedirs(os.path.dirname(filename))
+    except Exception:
+        pass
+
+    text_file = open(filename, "w")
+    text_file.write(txt)
+    text_file.close()
+
+
 def check_for_updates():
     """
     Checks if cryolo updates are available
@@ -435,10 +507,13 @@ def check_for_updates():
     """
     try:
         import cryolo
+
         with urllib.request.urlopen(
-                "https://pypi.org/pypi/cryolo/json") as url:
+            url="https://pypi.org/pypi/cryolo/json", timeout=5
+        ) as url:
             data = json.loads(url.read().decode())
             from distutils.version import LooseVersion as V
+
             current_version = cryolo.__version__
             latest_version = current_version
             for ver in data["releases"].keys():
@@ -450,9 +525,14 @@ def check_for_updates():
                 print("New version of crYOLO available")
                 print("Local version:\t\t", current_version)
                 print("Latest version:\t\t", latest_version)
-                print("More information here:\n",
-                      "http://sphire.mpg.de/wiki/doku.php?id=pipeline:window:cryolo")
+                print(
+                    "More information here:\n",
+                    "http://sphire.mpg.de/wiki/doku.php?id=pipeline:window:cryolo",
+                )
                 print("###############################################")
     except Exception as e:
+        print("###############################################")
+        print("Skip version check, as it failed with the following error:")
         print(e)
-        pass
\ No newline at end of file
+        print("###############################################")
+        pass
